@@ -32,7 +32,7 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
     PetscCall(PetscViewerASCIIPushSynchronized(viewer));
     PetscCall(PetscViewerGetFormat(viewer, &format));
     if (format == PETSC_VIEWER_LOAD_BALANCE) {
-      PetscInt      i, nmax = 0, nmin = PETSC_MAX_INT, navg = 0, *nz, nzlocal;
+      PetscInt      i, nmax = 0, nmin = PETSC_INT_MAX, navg = 0, *nz, nzlocal;
       DMDALocalInfo info;
       PetscMPIInt   size;
       PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)da), &size));
@@ -40,7 +40,7 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
       nzlocal = info.xm * info.ym * info.zm;
       PetscCall(PetscMalloc1(size, &nz));
       PetscCallMPI(MPI_Allgather(&nzlocal, 1, MPIU_INT, nz, 1, MPIU_INT, PetscObjectComm((PetscObject)da)));
-      for (i = 0; i < (PetscInt)size; i++) {
+      for (i = 0; i < size; i++) {
         nmax = PetscMax(nmax, nz[i]);
         nmin = PetscMin(nmin, nz[i]);
         navg += nz[i];
@@ -50,7 +50,7 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
       PetscCall(PetscViewerASCIIPrintf(viewer, "  Load Balance - Grid Points: Min %" PetscInt_FMT "  avg %" PetscInt_FMT "  max %" PetscInt_FMT "\n", nmin, navg, nmax));
       PetscFunctionReturn(PETSC_SUCCESS);
     }
-    if (format != PETSC_VIEWER_ASCII_VTK_DEPRECATED && format != PETSC_VIEWER_ASCII_VTK_CELL_DEPRECATED && format != PETSC_VIEWER_ASCII_GLVIS) {
+    if (format != PETSC_VIEWER_ASCII_GLVIS) {
       DMDALocalInfo info;
       PetscCall(DMDAGetLocalInfo(da, &info));
       PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "Processor [%d] M %" PetscInt_FMT " N %" PetscInt_FMT " P %" PetscInt_FMT " m %" PetscInt_FMT " n %" PetscInt_FMT " p %" PetscInt_FMT " w %" PetscInt_FMT " s %" PetscInt_FMT "\n", rank, dd->M, dd->N, dd->P, dd->m, dd->n, dd->p, dd->w, dd->s));
@@ -71,7 +71,6 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
       PetscCall(PetscViewerFlush(viewer));
       PetscCall(PetscViewerASCIIPopSynchronized(viewer));
     } else if (format == PETSC_VIEWER_ASCII_GLVIS) PetscCall(DMView_DA_GLVis(da, viewer));
-    else PetscCall(DMView_DA_VTK(da, viewer));
   } else if (isdraw) {
     PetscDraw       draw;
     PetscReal       ymin = -1.0, ymax = (PetscReal)dd->N;
@@ -124,13 +123,13 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
         xmax = (dd->xe - 1) / dd->w;
 
         /* identify which processor owns the box */
-        PetscCall(PetscSNPrintf(node, sizeof(node), "%d", (int)rank));
+        PetscCall(PetscSNPrintf(node, sizeof(node), "%d", rank));
         PetscCall(PetscDrawString(draw, xmin + (dd->M + 1) * k + .2, ymin + .3, PETSC_DRAW_RED, node));
         /* put in numbers*/
         base = (dd->base + (dd->xe - dd->xs) * (dd->ye - dd->ys) * (k - dd->zs)) / dd->w;
         for (y = ymin; y <= ymax; y++) {
           for (x = xmin + (dd->M + 1) * k; x <= xmax + (dd->M + 1) * k; x++) {
-            PetscCall(PetscSNPrintf(node, sizeof(node), "%d", (int)base++));
+            PetscCall(PetscSNPrintf(node, sizeof(node), "%" PetscInt_FMT, base++));
             PetscCall(PetscDrawString(draw, x, y, PETSC_DRAW_BLACK, node));
           }
         }
@@ -190,13 +189,11 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
 
 PetscErrorCode DMSetUp_DA_3D(DM da)
 {
-  DM_DA          *dd           = (DM_DA *)da->data;
-  const PetscInt  M            = dd->M;
-  const PetscInt  N            = dd->N;
-  const PetscInt  P            = dd->P;
-  PetscInt        m            = dd->m;
-  PetscInt        n            = dd->n;
-  PetscInt        p            = dd->p;
+  DM_DA          *dd = (DM_DA *)da->data;
+  const PetscInt  M  = dd->M;
+  const PetscInt  N  = dd->N;
+  const PetscInt  P  = dd->P;
+  PetscMPIInt     m, n, p;
   const PetscInt  dof          = dd->w;
   const PetscInt  s            = dd->s;
   DMBoundaryType  bx           = dd->bx;
@@ -211,12 +208,12 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
   PetscInt        xs = 0, xe, ys = 0, ye, zs = 0, ze, x = 0, y = 0, z = 0;
   PetscInt        Xs, Xe, Ys, Ye, Zs, Ze, IXs, IXe, IYs, IYe, IZs, IZe, pm;
   PetscInt        left, right, up, down, bottom, top, i, j, k, *idx, nn;
-  PetscInt        n0, n1, n2, n3, n4, n5, n6, n7, n8, n9, n10, n11, n12, n14;
-  PetscInt        n15, n16, n17, n18, n19, n20, n21, n22, n23, n24, n25, n26;
+  PetscMPIInt     n0, n1, n2, n3, n4, n5, n6, n7, n8, n9, n10, n11, n12, n14;
+  PetscMPIInt     n15, n16, n17, n18, n19, n20, n21, n22, n23, n24, n25, n26;
   PetscInt       *bases, *ldims, base, x_t, y_t, z_t, s_t, count, s_x, s_y, s_z;
-  PetscInt        sn0 = 0, sn1 = 0, sn2 = 0, sn3 = 0, sn5 = 0, sn6 = 0, sn7 = 0;
-  PetscInt        sn8 = 0, sn9 = 0, sn11 = 0, sn15 = 0, sn24 = 0, sn25 = 0, sn26 = 0;
-  PetscInt        sn17 = 0, sn18 = 0, sn19 = 0, sn20 = 0, sn21 = 0, sn23 = 0;
+  PetscMPIInt     sn0 = 0, sn1 = 0, sn2 = 0, sn3 = 0, sn5 = 0, sn6 = 0, sn7 = 0;
+  PetscMPIInt     sn8 = 0, sn9 = 0, sn11 = 0, sn15 = 0, sn24 = 0, sn25 = 0, sn26 = 0;
+  PetscMPIInt     sn17 = 0, sn18 = 0, sn19 = 0, sn20 = 0, sn21 = 0, sn23 = 0;
   Vec             local, global;
   VecScatter      gtol;
   IS              to, from;
@@ -228,23 +225,26 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
 #if !defined(PETSC_USE_64BIT_INDICES)
   PetscCheck(((PetscInt64)M) * ((PetscInt64)N) * ((PetscInt64)P) * ((PetscInt64)dof) <= (PetscInt64)PETSC_MPI_INT_MAX, comm, PETSC_ERR_INT_OVERFLOW, "Mesh of %" PetscInt_FMT " by %" PetscInt_FMT " by %" PetscInt_FMT " by %" PetscInt_FMT " (dof) is too large for 32-bit indices", M, N, P, dof);
 #endif
+  PetscCall(PetscMPIIntCast(dd->m, &m));
+  PetscCall(PetscMPIIntCast(dd->n, &n));
+  PetscCall(PetscMPIIntCast(dd->p, &p));
 
   PetscCallMPI(MPI_Comm_size(comm, &size));
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
 
   if (m != PETSC_DECIDE) {
-    PetscCheck(m >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Non-positive number of processors in X direction: %" PetscInt_FMT, m);
-    PetscCheck(m <= size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many processors in X direction: %" PetscInt_FMT " %d", m, size);
+    PetscCheck(m >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Non-positive number of processors in X direction: %d", m);
+    PetscCheck(m <= size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many processors in X direction: %d %d", m, size);
   }
   if (n != PETSC_DECIDE) {
-    PetscCheck(n >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Non-positive number of processors in Y direction: %" PetscInt_FMT, n);
-    PetscCheck(n <= size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many processors in Y direction: %" PetscInt_FMT " %d", n, size);
+    PetscCheck(n >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Non-positive number of processors in Y direction: %d", n);
+    PetscCheck(n <= size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many processors in Y direction: %d %d", n, size);
   }
   if (p != PETSC_DECIDE) {
-    PetscCheck(p >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Non-positive number of processors in Z direction: %" PetscInt_FMT, p);
-    PetscCheck(p <= size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many processors in Z direction: %" PetscInt_FMT " %d", p, size);
+    PetscCheck(p >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Non-positive number of processors in Z direction: %d", p);
+    PetscCheck(p <= size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many processors in Z direction: %d %d", p, size);
   }
-  PetscCheck(m <= 0 || n <= 0 || p <= 0 || m * n * p == size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "m %" PetscInt_FMT " * n %" PetscInt_FMT " * p %" PetscInt_FMT " != size %d", m, n, p, size);
+  PetscCheck(m <= 0 || n <= 0 || p <= 0 || m * n * p == size, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "m %d * n %d * p %d != size %d", m, n, p, size);
 
   /* Partition the array among the processors */
   if (m == PETSC_DECIDE && n != PETSC_DECIDE && p != PETSC_DECIDE) {
@@ -262,11 +262,11 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
       if (m * n * p == size) break;
       m--;
     }
-    PetscCheck(m, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "bad p value: p = %" PetscInt_FMT, p);
+    PetscCheck(m, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "bad p value: p = %d", p);
     if (M > N && m < n) {
-      PetscInt _m = m;
-      m           = n;
-      n           = _m;
+      PetscMPIInt _m = m;
+      m              = n;
+      n              = _m;
     }
   } else if (m == PETSC_DECIDE && n != PETSC_DECIDE && p == PETSC_DECIDE) {
     /* try for squarish distribution */
@@ -277,11 +277,11 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
       if (m * n * p == size) break;
       m--;
     }
-    PetscCheck(m, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "bad n value: n = %" PetscInt_FMT, n);
+    PetscCheck(m, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "bad n value: n = %d", n);
     if (M > P && m < p) {
-      PetscInt _m = m;
-      m           = p;
-      p           = _m;
+      PetscMPIInt _m = m;
+      m              = p;
+      p              = _m;
     }
   } else if (m != PETSC_DECIDE && n == PETSC_DECIDE && p == PETSC_DECIDE) {
     /* try for squarish distribution */
@@ -292,15 +292,15 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
       if (m * n * p == size) break;
       n--;
     }
-    PetscCheck(n, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "bad m value: m = %" PetscInt_FMT, n);
+    PetscCheck(n, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "bad m value: m = %d", n);
     if (N > P && n < p) {
-      PetscInt _n = n;
-      n           = p;
-      p           = _n;
+      PetscMPIInt _n = n;
+      n              = p;
+      p              = _n;
     }
   } else if (m == PETSC_DECIDE && n == PETSC_DECIDE && p == PETSC_DECIDE) {
     /* try for squarish distribution */
-    n = (PetscInt)(0.5 + PetscPowReal(((PetscReal)N * N) * ((PetscReal)size) / ((PetscReal)P * M), (PetscReal)(1. / 3.)));
+    n = (PetscMPIInt)(0.5 + PetscPowReal(((PetscReal)N * N) * ((PetscReal)size) / ((PetscReal)P * M), (PetscReal)(1. / 3.)));
     if (!n) n = 1;
     while (n > 0) {
       pm = size / n;
@@ -308,7 +308,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
       n--;
     }
     if (!n) n = 1;
-    m = (PetscInt)(0.5 + PetscSqrtReal(((PetscReal)M) * ((PetscReal)size) / ((PetscReal)P * n)));
+    m = (PetscMPIInt)(0.5 + PetscSqrtReal(((PetscReal)M) * ((PetscReal)size) / ((PetscReal)P * n)));
     if (!m) m = 1;
     while (m > 0) {
       p = size / (m * n);
@@ -316,16 +316,16 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
       m--;
     }
     if (M > P && m < p) {
-      PetscInt _m = m;
-      m           = p;
-      p           = _m;
+      PetscMPIInt _m = m;
+      m              = p;
+      p              = _m;
     }
   } else PetscCheck(m * n * p == size, PetscObjectComm((PetscObject)da), PETSC_ERR_ARG_OUTOFRANGE, "Given Bad partition");
 
   PetscCheck(m * n * p == size, PetscObjectComm((PetscObject)da), PETSC_ERR_PLIB, "Could not find good partition");
-  PetscCheck(M >= m, PetscObjectComm((PetscObject)da), PETSC_ERR_ARG_OUTOFRANGE, "Partition in x direction is too fine! %" PetscInt_FMT " %" PetscInt_FMT, M, m);
-  PetscCheck(N >= n, PetscObjectComm((PetscObject)da), PETSC_ERR_ARG_OUTOFRANGE, "Partition in y direction is too fine! %" PetscInt_FMT " %" PetscInt_FMT, N, n);
-  PetscCheck(P >= p, PetscObjectComm((PetscObject)da), PETSC_ERR_ARG_OUTOFRANGE, "Partition in z direction is too fine! %" PetscInt_FMT " %" PetscInt_FMT, P, p);
+  PetscCheck(M >= m, PetscObjectComm((PetscObject)da), PETSC_ERR_ARG_OUTOFRANGE, "Partition in x direction is too fine! %" PetscInt_FMT " %d", M, m);
+  PetscCheck(N >= n, PetscObjectComm((PetscObject)da), PETSC_ERR_ARG_OUTOFRANGE, "Partition in y direction is too fine! %" PetscInt_FMT " %d", N, n);
+  PetscCheck(P >= p, PetscObjectComm((PetscObject)da), PETSC_ERR_ARG_OUTOFRANGE, "Partition in z direction is too fine! %" PetscInt_FMT " %d", P, p);
 
   /*
      Determine locally owned region
@@ -360,6 +360,10 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
   }
   z = lz[rank / (m * n)];
 
+  PetscCheck((x > s) || (bx != DM_BOUNDARY_MIRROR), PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Local x-width of domain x %" PetscInt_FMT " is smaller than stencil width s %" PetscInt_FMT " with mirror", x, s);
+  PetscCheck((y > s) || (by != DM_BOUNDARY_MIRROR), PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Local y-width of domain y %" PetscInt_FMT " is smaller than stencil width s %" PetscInt_FMT " with mirror", y, s);
+  PetscCheck((z > s) || (bz != DM_BOUNDARY_MIRROR), PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Local z-width of domain z %" PetscInt_FMT " is smaller than stencil width s %" PetscInt_FMT " with mirror", z, s);
+
   /* note this is different than x- and y-, as we will handle as an important special
    case when p=P=1 and DM_BOUNDARY_PERIODIC and s > z.  This is to deal with 2D problems
    in a 3D code.  Additional code for this case is noted with "2d case" comments */
@@ -1089,7 +1093,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
     n26 = sn26;
   }
 
-  if (((stencil_type == DMDA_STENCIL_STAR) || (bx != DM_BOUNDARY_PERIODIC && bx) || (by != DM_BOUNDARY_PERIODIC && by) || (bz != DM_BOUNDARY_PERIODIC && bz))) {
+  if ((stencil_type == DMDA_STENCIL_STAR) || (bx != DM_BOUNDARY_PERIODIC && bx) || (by != DM_BOUNDARY_PERIODIC && by) || (bz != DM_BOUNDARY_PERIODIC && bz)) {
     /*
         Recompute the local to global mappings, this time keeping the
       information about the cross corner processor numbers.
@@ -1146,7 +1150,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
           for (j = 0; j < x_t; j++) idx[nn++] = s_t++;
         } else if (Zs - zs < 0) {
           if (bz == DM_BOUNDARY_MIRROR) {
-            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + x * i + (s_z - k - 1) * x * y;
+            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + x * i + (s_z - k) * x * y;
           } else {
             for (j = 0; j < x; j++) idx[nn++] = -1;
           }
@@ -1214,7 +1218,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
           for (j = 0; j < x_t; j++) idx[nn++] = s_t++;
         } else if (Ys - ys < 0) {
           if (by == DM_BOUNDARY_MIRROR) {
-            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + k * x * y + (s_y - i) * x;
+            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + k * x * y + (s_y - i + 1) * x;
           } else {
             for (j = 0; j < x; j++) idx[nn++] = -1;
           }
@@ -1239,7 +1243,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
           for (j = 0; j < s_x; j++) idx[nn++] = s_t++;
         } else if (Xs - xs < 0) {
           if (bx == DM_BOUNDARY_MIRROR) {
-            for (j = 0; j < s_x; j++) idx[nn++] = bases[rank] + s_x - j - 1 + k * x * y + i * x;
+            for (j = 0; j < s_x; j++) idx[nn++] = bases[rank] + s_x - j - 1 + k * x * y + i * x + 1;
           } else {
             for (j = 0; j < s_x; j++) idx[nn++] = -1;
           }
@@ -1257,7 +1261,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
           for (j = 0; j < s_x; j++) idx[nn++] = s_t++;
         } else if (xe - Xe < 0) {
           if (bx == DM_BOUNDARY_MIRROR) {
-            for (j = 0; j < s_x; j++) idx[nn++] = bases[rank] + x - j - 1 + k * x * y + i * x;
+            for (j = 0; j < s_x; j++) idx[nn++] = bases[rank] + x - j - 1 + k * x * y + i * x - 1;
           } else {
             for (j = 0; j < s_x; j++) idx[nn++] = -1;
           }
@@ -1282,7 +1286,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
           for (j = 0; j < x_t; j++) idx[nn++] = s_t++;
         } else if (ye - Ye < 0) {
           if (by == DM_BOUNDARY_MIRROR) {
-            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + k * x * y + (y - i) * x;
+            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + k * x * y + (y - i - 1) * x;
           } else {
             for (j = 0; j < x; j++) idx[nn++] = -1;
           }
@@ -1350,7 +1354,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
           for (j = 0; j < x_t; j++) idx[nn++] = s_t++;
         } else if (ze - Ze < 0) {
           if (bz == DM_BOUNDARY_MIRROR) {
-            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + (z - k - 1) * x * y + i * x;
+            for (j = 0; j < x; j++) idx[nn++] = bases[rank] + j + (z - k - 2) * x * y + i * x;
           } else {
             for (j = 0; j < x; j++) idx[nn++] = -1;
           }
@@ -1433,20 +1437,20 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   DMDACreate3d - Creates an object that will manage the communication of three-dimensional
-  regular array data that is distributed across some processors.
+  regular array data that is distributed across one or more MPI processes.
 
   Collective
 
   Input Parameters:
 + comm         - MPI communicator
 . bx           - type of x ghost nodes the array have.
-         Use one of `DM_BOUNDARY_NONE`, `DM_BOUNDARY_GHOSTED`, `DM_BOUNDARY_PERIODIC`.
+                 Use one of `DM_BOUNDARY_NONE`, `DM_BOUNDARY_GHOSTED`, `DM_BOUNDARY_PERIODIC`.
 . by           - type of y ghost nodes the array have.
-         Use one of `DM_BOUNDARY_NONE`, `DM_BOUNDARY_GHOSTED`, `DM_BOUNDARY_PERIODIC`.
+                 Use one of `DM_BOUNDARY_NONE`, `DM_BOUNDARY_GHOSTED`, `DM_BOUNDARY_PERIODIC`.
 . bz           - type of z ghost nodes the array have.
-         Use one of `DM_BOUNDARY_NONE`, `DM_BOUNDARY_GHOSTED`, `DM_BOUNDARY_PERIODIC`.
+                 Use one of `DM_BOUNDARY_NONE`, `DM_BOUNDARY_GHOSTED`, `DM_BOUNDARY_PERIODIC`.
 . stencil_type - Type of stencil (`DMDA_STENCIL_STAR` or `DMDA_STENCIL_BOX`)
 . M            - global dimension in x direction of the array
 . N            - global dimension in y direction of the array
@@ -1471,10 +1475,14 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
 . -da_processors_x <MX> - number of processors in x direction
 . -da_processors_y <MY> - number of processors in y direction
 . -da_processors_z <MZ> - number of processors in z direction
+. -da_bd_x <bx>         - boundary type in x direction
+. -da_bd_y <by>         - boundary type in y direction
+. -da_bd_z <bz>         - boundary type in x direction
+. -da_bd_all <bt>       - boundary type in all directions
 . -da_refine_x <rx>     - refinement ratio in x direction
 . -da_refine_y <ry>     - refinement ratio in y direction
 . -da_refine_z <rz>     - refinement ratio in z directio
-- -da_refine <n>        - refine the DMDA n times before creating it
+- -da_refine <n>        - refine the `DMDA` n times before creating it
 
   Level: beginner
 
@@ -1493,13 +1501,13 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
 
   You must call `DMSetUp()` after this call before using this `DM`.
 
-  If you wish to use the options database to change values in the `DMDA` call `DMSetFromOptions()` after this call
+  To use the options database to change values in the `DMDA` call `DMSetFromOptions()` after this call
   but before `DMSetUp()`.
 
-.seealso: `DM`, `DMDA`, `DMDestroy()`, `DMView()`, `DMDACreate1d()`, `DMDACreate2d()`, `DMGlobalToLocalBegin()`, `DMDAGetRefinementFactor()`,
+.seealso: [](sec_struct), `DM`, `DMDA`, `DMDestroy()`, `DMView()`, `DMDACreate1d()`, `DMDACreate2d()`, `DMGlobalToLocalBegin()`, `DMDAGetRefinementFactor()`,
           `DMGlobalToLocalEnd()`, `DMLocalToGlobalBegin()`, `DMLocalToLocalBegin()`, `DMLocalToLocalEnd()`, `DMDASetRefinementFactor()`,
           `DMDAGetInfo()`, `DMCreateGlobalVector()`, `DMCreateLocalVector()`, `DMDACreateNaturalVector()`, `DMLoad()`, `DMDAGetOwnershipRanges()`,
-          `DMStagCreate3d()`
+          `DMStagCreate3d()`, `DMBoundaryType`
 @*/
 PetscErrorCode DMDACreate3d(MPI_Comm comm, DMBoundaryType bx, DMBoundaryType by, DMBoundaryType bz, DMDAStencilType stencil_type, PetscInt M, PetscInt N, PetscInt P, PetscInt m, PetscInt n, PetscInt p, PetscInt dof, PetscInt s, const PetscInt lx[], const PetscInt ly[], const PetscInt lz[], DM *da)
 {
