@@ -368,7 +368,7 @@ static PetscErrorCode SNESReset_VINEWTONSSLS(SNES snes)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode SNESSetFromOptions_VINEWTONSSLS(SNES snes, PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode SNESSetFromOptions_VINEWTONSSLS(SNES snes, PetscOptionItems PetscOptionsObject)
 {
   PetscFunctionBegin;
   PetscCall(SNESSetFromOptions_VI(snes, PetscOptionsObject));
@@ -419,6 +419,8 @@ PETSC_EXTERN PetscErrorCode SNESCreate_VINEWTONSSLS(SNES snes)
 
   snes->alwayscomputesfinalresidual = PETSC_FALSE;
 
+  PetscCall(SNESParametersInitialize(snes));
+
   PetscCall(PetscNew(&vi));
   snes->data = (void *)vi;
 
