@@ -18,7 +18,7 @@
 - sp - separator character
 
   Output Parameters:
-+ argc - the number of entries in the array
++ argc - the number of entries in `args`
 - args - an array of the entries with a `NULL` at the end
 
   Level: intermediate
@@ -29,17 +29,17 @@
   Developer Notes:
   Uses raw `malloc()` and does not call error handlers since this may be used before PETSc is initialized.
 
-  Used to generate argc, args arguments passed to `MPI_Init()`
+  Used to generate `argc`, `args` arguments passed to `MPI_Init()`
 
 .seealso: `PetscStrToArrayDestroy()`, `PetscToken`, `PetscTokenCreate()`
 @*/
 PetscErrorCode PetscStrToArray(const char s[], char sp, int *argc, char ***args)
 {
-  int       i, j, n, *lens, cnt = 0;
+  int       n, i, j, *lens, cnt = 0;
   PetscBool flg = PETSC_FALSE;
 
   if (!s) n = 0;
-  else n = strlen(s);
+  else n = (int)strlen(s);
   *argc = 0;
   *args = NULL;
   for (; n > 0; n--) { /* remove separator chars at the end - and will empty the string if all chars are separator chars */
@@ -59,7 +59,7 @@ PetscErrorCode PetscStrToArray(const char s[], char sp, int *argc, char ***args)
   }
   (*args) = (char **)malloc(((*argc) + 1) * sizeof(char *));
   if (!*args) return PETSC_ERR_MEM;
-  lens = (int *)malloc((*argc) * sizeof(int));
+  lens = (int *)malloc(((*argc) + 1) * sizeof(int));
   if (!lens) return PETSC_ERR_MEM;
   for (i = 0; i < *argc; i++) lens[i] = 0;
 
@@ -144,8 +144,7 @@ PetscErrorCode PetscStrToArrayDestroy(int argc, char **args)
   Level: intermediate
 
   Note:
-  If `t` has previously been allocated then that memory is lost, you may need to `PetscStrArrayDestroy()`
-  the array before calling this routine.
+  Use `PetscStrArrayDestroy()` to free the memory.
 
 .seealso: `PetscStrallocpy()`, `PetscStrArrayDestroy()`, `PetscStrNArrayallocpy()`
 @*/
@@ -201,6 +200,9 @@ PetscErrorCode PetscStrArrayDestroy(char ***list)
 
   Level: intermediate
 
+  Note:
+  Use `PetscStrNArrayDestroy()` to free the memory.
+
 .seealso: `PetscStrallocpy()`, `PetscStrArrayallocpy()`, `PetscStrNArrayDestroy()`
 @*/
 PetscErrorCode PetscStrNArrayallocpy(PetscInt n, const char *const *list, char ***t)
@@ -340,7 +342,7 @@ PetscErrorCode PetscStrendswithwhich(const char a[], const char *const *bs, Pets
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-struct _p_PetscToken {
+struct _n_PetscToken {
   char  token;
   char *array;
   char *current;
@@ -368,9 +370,11 @@ struct _p_PetscToken {
 
   If the separator character is + and the string is xxxx then the first and only token found will be a pointer to a `NULL` terminated xxxx
 
+  Do not change or free the value of `result`
+
 .seealso: `PetscToken`, `PetscTokenCreate()`, `PetscTokenDestroy()`
 @*/
-PetscErrorCode PetscTokenFind(PetscToken a, char *result[])
+PetscErrorCode PetscTokenFind(PetscToken a, const char *result[])
 {
   char *ptr, token;
 
@@ -477,8 +481,8 @@ PetscErrorCode PetscTokenDestroy(PetscToken *a)
 @*/
 PetscErrorCode PetscStrInList(const char str[], const char list[], char sep, PetscBool *found)
 {
-  PetscToken token;
-  char      *item;
+  PetscToken  token;
+  const char *item;
 
   PetscFunctionBegin;
   PetscAssertPointer(found, 4);
@@ -528,9 +532,12 @@ PetscErrorCode PetscGetPetscDir(const char *dir[])
   Level: developer
 
   Notes:
-  Replaces ${PETSC_ARCH},${PETSC_DIR},${PETSC_LIB_DIR},${DISPLAY},
-      ${HOMEDIRECTORY},${WORKINGDIRECTORY},${USERNAME}, ${HOSTNAME}, ${PETSC_MAKE} with appropriate values
-  as well as any environmental variables.
+  Replaces
+.vb
+    ${PETSC_ARCH}, ${PETSC_DIR}, ${PETSC_LIB_DIR}, ${DISPLAY},
+    ${HOMEDIRECTORY}, ${WORKINGDIRECTORY}, ${USERNAME}, ${HOSTNAME}, ${PETSC_MAKE}
+.ve
+  with appropriate values as well as any environmental variables.
 
   `PETSC_LIB_DIR` uses the environmental variable if it exists. `PETSC_ARCH` and `PETSC_DIR` use what
   PETSc was built with and do not use environmental variables.
@@ -550,7 +557,7 @@ PetscErrorCode PetscStrreplace(MPI_Comm comm, const char aa[], char b[], size_t
   PetscFunctionBegin;
   PetscAssertPointer(aa, 2);
   PetscAssertPointer(b, 3);
-  if (aa == b) PetscCall(PetscStrallocpy(aa, (char **)&a));
+  if (aa == b) PetscCall(PetscStrallocpy(aa, &a));
   PetscCall(PetscMalloc1(len, &work));
 
   /* get values for replaced variables */
@@ -599,7 +606,7 @@ PetscErrorCode PetscStrreplace(MPI_Comm comm, const char aa[], char b[], size_t
   }
   i = 0;
   while (r[i]) {
-    tfree = (char *)r[i];
+    tfree = r[i];
     PetscCall(PetscFree(tfree));
     i++;
   }
@@ -628,7 +635,7 @@ PetscErrorCode PetscStrreplace(MPI_Comm comm, const char aa[], char b[], size_t
 /*@C
   PetscStrcmpAny - Determines whether a string matches any of a list of strings.
 
-  Not Collective
+  Not Collective, No Fortran Support
 
   Input Parameters:
 + src - pointer to input the string
